Class: LegoTechSelenium::Actions
- Inherits:
-
Object
- Object
- LegoTechSelenium::Actions
- Defined in:
- lib/ui/actions/Action.rb
Instance Method Summary collapse
-
#test(driver, action) ⇒ Object
A function that performs the given action against the webpage given the driver and the action.
Instance Method Details
#test(driver, action) ⇒ Object
A function that performs the given action against the webpage given the driver and the action
16 17 18 |
# File 'lib/ui/actions/Action.rb', line 16 def test(driver, action) raise "Test function in the Actions.rb file has not been overriden" end |