Class: LegoTechSelenium::Driver
- Inherits:
-
Object
- Object
- LegoTechSelenium::Driver
- Defined in:
- lib/ui/driver/Driver.rb
Instance Method Summary collapse
-
#initialize(driver) ⇒ Driver
constructor
Pass in an instance of the driver.
-
#set_implicit_wait(implicit_wait) ⇒ Object
Set the amount of time the driver should wait when searching for elements.
-
#set_navigate_to(navigate_to) ⇒ Object
The URL to navigate to.
-
#set_page_load(page_load) ⇒ Object
Sets the amount of time to wait for a page load to complete before throwing an error.
-
#set_script_tiemout(script_tiemout) ⇒ Object
Sets the amount of time to wait for an asynchronous script to finish execution before throwing an error.
Constructor Details
#initialize(driver) ⇒ Driver
Pass in an instance of the driver
10 11 12 |
# File 'lib/ui/driver/Driver.rb', line 10 def initialize(driver) @driver = driver end |
Instance Method Details
#set_implicit_wait(implicit_wait) ⇒ Object
Set the amount of time the driver should wait when searching for elements.
16 17 |
# File 'lib/ui/driver/Driver.rb', line 16 def set_implicit_wait(implicit_wait) end |
#set_navigate_to(navigate_to) ⇒ Object
The URL to navigate to
31 32 |
# File 'lib/ui/driver/Driver.rb', line 31 def set_navigate_to(navigate_to) end |
#set_page_load(page_load) ⇒ Object
Sets the amount of time to wait for a page load to complete before throwing an error.
21 22 |
# File 'lib/ui/driver/Driver.rb', line 21 def set_page_load(page_load) end |
#set_script_tiemout(script_tiemout) ⇒ Object
Sets the amount of time to wait for an asynchronous script to finish execution before throwing an error.
26 27 |
# File 'lib/ui/driver/Driver.rb', line 26 def set_script_tiemout(script_tiemout) end |